@@ -22,6 +22,13 @@
 #include "grantleecontactformatter.h"
 #include "grantleetheme/grantleetheme.h"
 #include "grantleecontactutils.h"
+#include "../contactobject/contactgrantleeaddressobject.h"
+#include "../contactobject/contactgrantleephoneobject.h"
+#include "../contactobject/contactgrantleeimobject.h"
+#include "../contactobject/contactgrantleegeoobject.h"
+#include "../contactobject/contactgrantleecryptoobject.h"
+#include "../contactobject/contactgrantleewebsite.h"
+#include "../contactobject/contactgrantleeemail.h"
 
 #include <KContacts/Addressee>
 #include <grantlee/context.h>
